Functions
=========

-  predicate(p)
-  binary(true=TRUE, false=FALSE)
-  assert true != false
-  string => ==
-  list/set => s in seq

-  element(seq)
-  assert unique
-  show?
-  position(seq)
-  show?
-  offset? a, A, 0, 1
-  padding

-  number: float or integer?
-  range=None
-  word => alnum
-  letter => alnum, upper=True, lower=True
-  digit

-  transformer???

Functionality
=============

-  multiple: integer() => integers()
-  \_single(test, ...)
-  \_multiple(test, ..., sep=" ", strip=True)

   -  all()
   -  [... if x]

-  strip()?

Miscellaneous
=============

-  tests
-  coverage (tox, travis)
-  dependency check
